@@ -1401,7 +1401,7 @@ g_unescape_uri_string (const char *escaped,
   g_assert (out - result <= len);
   *out = '\0';
 
-  if (in != in_end)
+  if (in != in_end || !g_utf8_validate (result, -1, NULL))
     {
       g_free (result);
       return NULL;
@@ -1494,7 +1494,7 @@ g_filename_from_uri (const gchar *uri,
   if (!has_case_prefix (uri, "file:/"))
     {
       g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_BAD_URI,
-		   _("The URI '%s' is not an absolute URI using the file scheme"),
+		   _("The URI '%s' is not an absolute URI using the \"file\" scheme"),
 		   uri);
       return NULL;
     }
